@@ -76,7 +76,8 @@ pub struct PayloadRawParts {
     async fn {{snakecase operationId}}(
         &self,
         payload: PayloadRawParts,
-        request: {{~#if security}}Self::AuthorizedData{{~else~}}HttpRequest{{~/if}},
+        request: &HttpRequest,
+        {{~#if security}}auth_data: Self::AuthorizedData,{{~/if}}
         parameters: super::{{snakecase operationId}}::Parameters,
         {{#unless noBody~}} body: super::{{snakecase operationId}}::Body, {{~/unless}}
     ) -> Result<super::{{snakecase operationId}}::Success, super::{{snakecase operationId}}::Error<Self::Error>>;
@@ -85,7 +86,7 @@ pub struct PayloadRawParts {
 {{~#*inline "auth_fn_trait"}}
     async fn {{snakecase key}}(
         &self,
-        request: actix_web::HttpRequest,
+        request: &actix_web::HttpRequest,
         payload: &PayloadRawParts,
     ) -> Result<Self::AuthorizedData, Self::Error>;
 {{~/inline}}
@@ -98,7 +99,7 @@ pub trait {{camelcase info.title}} {
     type Error: std::error::Error;
     type HandlerResult: Into<actix_web::body::AnyBody>;
 
-    fn handle_error<E: std::error::Error>(e: &E) -> Self::HandlerResult;
+    fn handle_error<E: std::error::Error>(req: &HttpRequest, e: &E) -> Self::HandlerResult;
 
 {{~#each paths}}
     {{~#with get}}{{~> operation_fn_trait noBody=true}}{{~/with}}
@@ -162,7 +163,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                 {{~/with}}
             )
             {{~/if}}
-            .body(<Server as {{camelcase ../title}}>::handle_error(&err)),
+            .body(<Server as {{camelcase ../title}}>::handle_error(&request, &err)),
     };
 
     {{~#unless noBody}}
@@ -174,7 +175,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                     Ok(body) => body,
                     Err(e) => return HttpResponse::BadRequest()
                         .content_type("application/json")
-                        .body(<Server as {{camelcase ../title}}>::handle_error(&e)),
+                        .body(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
                 };
             {{~/with}}
 
@@ -184,7 +185,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
                     Ok(body) => body,
                     Err(e) => return HttpResponse::BadRequest()
                         .content_type("application/x-www-form-urlencoded")
-                        .body(<Server as {{camelcase ../title}}>::handle_error(&e)),
+                        .body(<Server as {{camelcase ../title}}>::handle_error(&request, &e)),
                 };
             {{~/with}}
 
@@ -233,17 +234,17 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
     {{~#if security }}
         {{~#each security as |obj|}}
             {{~#each obj as |o  key|}}
-                let request = match server.{{snakecase key}}(request, &payload_raw).await {
+                let auth_data = match server.{{snakecase key}}(&request, &payload_raw).await {
                     Ok(auth_data) => auth_data,
                     Err(e) => return HttpResponse::Unauthorized()
                         .content_type("application/json")
-                        .body(<Server as {{camelcase ../../title}}>::handle_error(&e)),
+                        .body(<Server as {{camelcase ../../title}}>::handle_error(&request, &e)),
                 };
             {{~/each}}
         {{~/each}}
     {{~/if}}
 
-    match server.{{snakecase operationId}}(payload_raw, request, parameters {{~#unless noBody}}, body{{/unless}}).await {
+    match server.{{snakecase operationId}}(payload_raw, {{~#if security}}&request, auth_data,{{~else~}}&request, {{~/if}}parameters {{~#unless noBody}}, body{{/unless}}).await {
         {{~#each responses}}
             {{~#if (not (eq @key "default"))}}
                 {{~#if (is_http_code_success @key)}}
@@ -291,7 +292,7 @@ async fn {{snakecase operationId}}<Server: {{camelcase title}}>(
         Err(Error::Unknown(err)) =>
             HttpResponse::Unauthorized()
                 .content_type("application/json")
-                .body(<Server as {{camelcase title}}>::handle_error(&err)),
+                .body(<Server as {{camelcase title}}>::handle_error(&request, &err)),
     }
 }
 {{~/inline}}
